@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2015-2019 Montel Laurent <montel@kde.org>
+   Copyright (C) 2015-2020 Laurent Montel <montel@kde.org>
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public
@@ -20,7 +20,7 @@
 #include "sieveeditorbookmarks.h"
 #include "sieveeditormainwindow.h"
 #include <QStandardPaths>
-#include <kbookmarkmanager.h>
+#include <KBookmarkManager>
 #include <KBookmarkMenu>
 #include <QDir>
 
